@@ -250,17 +250,28 @@ class MySMTPHandler(handlers.SMTPHandler):
         formatter = logging.Formatter(fmt=self.subject)
         return formatter.formatMessage(record)
 
+
 class AppTool(object):
     def __init__(self, app_name: str, app_path: str, local_config_dir: str=''):
-        self.app_name = app_name
-        self.app_path = app_path
-        self.config = {}
-        self.logger = None
+        self._app_name = app_name
+        self._app_path = app_path
+        self._config = {}
+        self._logger = None
 
         self.load_config(local_config_dir)
         self.init_logger()
 
 
+    @property
+    def config(self):
+        return self._config
+
+
+    @property
+    def logger(self):
+        return self._logger
+
+
     def load_config(self, local_config_dir: str = '') -> dict:
         """Load config locally
         
@@ -272,28 +283,28 @@ class AppTool(object):
         """
         assert(type(local_config_dir) == str)
 
-        sys.path.append(self.app_path)
+        sys.path.append(self._app_path)
         try:
-            config = __import__('config').CONFIG
+            self._config = __import__('config').CONFIG
         except Exception:
-            pass
+            self._config = {}
 
-        config_local_path = path.join(self.app_path, local_config_dir)
+        config_local_path = path.join(self._app_path, local_config_dir)
         sys.path.append(config_local_path)
         try:
             config_local = __import__('config_local').CONFIG
-            self.config = deep_merge(config, config_local)
+            self._config = deep_merge(self._config, config_local)
         except Exception:
-            pass        
+            pass
         
         if '--test' in sys.argv:
             try:
                 config_test = __import__('config_test').CONFIG
-                self.config = deep_merge(self.config, config_test)
+                self._config = deep_merge(self._config, config_test)
             except Exception:
                 pass
         
-        return self.config
+        return self._config
 
 
     def init_logger(self) -> logging.Logger:
@@ -303,22 +314,22 @@ class AppTool(object):
             [logger] -- Initialized logger.
         """
 
-        smtp = self.config.get('smtp')
-        mail = self.config.get('mail')
-        logConfig = self.config.get('log', {})
+        smtp = self._config.get('smtp')
+        mail = self._config.get('mail')
+        logConfig = self._config.get('log', {})
 
-        logs_path = path.join(self.app_path, 'logs')
+        logs_path = path.join(self._app_path, 'logs')
         if not os.path.exists(logs_path):
             os.mkdir(logs_path)
 
-        logger = logging.getLogger(self.app_name)
+        logger = logging.getLogger(self._app_name)
         logLevel = logConfig.get('level', logging.DEBUG)
         logger.setLevel(logLevel)
 
         logDest = logConfig.get('dest', [])
 
         if 'file' in logDest:
-            rf_handler = handlers.TimedRotatingFileHandler(path.join(logs_path, f'{self.app_name}.log'), when='D', interval=1, backupCount=7)
+            rf_handler = handlers.TimedRotatingFileHandler(path.join(logs_path, f'{self._app_name}.log'), when='D', interval=1, backupCount=7)
             rf_handler.suffix = "%Y-%m-%d_%H-%M-%S.log"
             rf_handler.level = logging.INFO
             rf_handler.setFormatter(logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
@@ -349,15 +360,15 @@ class AppTool(object):
             st_handler.level = logging.DEBUG
             st_handler.setFormatter(logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
             logger.addHandler(st_handler)
-        self.logger = logger
+        self._logger = logger
         return logger
 
 
     def send_email(self, subject: str, body: str, to_addrs=None, debug: bool=False) -> dict:
         """A shortcut of global send_email
         """
-        smtp = self.config['smtp']
-        mail = self.config['mail']
+        smtp = self._config.get('smtp')
+        mail = self._config.get('mail')
         #TODO: Use schema to validate smtp_config
         assert(smtp and mail)
         mail_to = to_addrs if to_addrs else mail['to']
@@ -382,6 +393,26 @@ class AppTool(object):
         return self.send_email(subject, body, to_addrs, debug)
 
 
+    def debug(self, msg, *args, **kwargs):
+        self._logger.debug(msg, *args, **kwargs)
+
+
+    def info(self, msg, *args, **kwargs):
+        self._logger.info(msg, *args, **kwargs)
+
+
+    def warn(self, msg, *args, **kwargs):
+        self._logger.warn(msg, *args, **kwargs)
+
+
+    def error(self, msg, *args, **kwargs):
+        self._logger.error(msg, *args, **kwargs)
+
+
+    def fatal(self, msg, *args, **kwargs):
+        self._logger.fatal(msg, *args, **kwargs)
+
+
     def log(self, reRaise=False, message=''):
         """Decorator
         !!! Should be decorated first to avoid being shielded by other decorators, such as @click.
@@ -412,7 +443,7 @@ class AppTool(object):
                 try:
                     return func(*args, **kw)
                 except Exception as ex:
-                    self.logger.exception(message if message else str(ex))
+                    self._logger.exception(message if message else str(ex))
                     if reRaise:
                         raise ex
             return wrapper
@@ -479,8 +510,8 @@ def random_sleep(min=0, max=3):
     time.sleep(random.uniform(min, max))
 
 
-def load_json(file_path):
-    data = None
+def load_json(file_path, default=None):
+    data = default
     if os.path.exists(file_path):
         with open(file_path, 'r', encoding='utf8') as fp:
             data = json.load(fp)
